//---------------------------------------------------------------------------
// File: TMainForm.cpp, TDx_Library, How The Components Work - Part 1
//
// Date: 16th January, 2004
// Last Updated: 18th May 2013
// Author: Darren John Dwyer
// Copyright: (c) 2002-2013 Darren John Dwyer, All Rights Reserved.
//
// Description:
// Most TDx_Library interface methods usually return a true or false result,
// which can be used to easily structure code for successful DirectX error handling.
//
// This example shows one way of coding an application using the boolean return results.
//
// void __fastcall TForm1::Button1Click(TObject *Sender)
// {
// if (Dx_Sound1->Create(NULL))
//     {
//     ShowMessage("DirectSound interface has been created successfully");
//     if (Dx_SoundBuffer1->CreateFromFile( "TEST.WAV", DSBufferDesc1, Dx_Sound1 ))
//         ShowMessage("DirectSoundBuffer has been created successfully");
//     else ShowMessage("DirectSoundBuffer could not be created successfully");
//     }
// else ShowMessage("DirectSound interface was not created");
// }
//
//---------------------------------------------------------------------------
#include <vcl\vcl.h>
//---------------------------------------------------------------------------
#pragma hdrstop
//---------------------------------------------------------------------------
#include "TMainForm.h"
//---------------------------------------------------------------------------
#if (__BORLANDC__ >= 0x0530) // BCB Version 3+
    #pragma package(smart_init)
#endif
//---------------------------------------------------------------------------
#pragma link "TDx_Sound"
#pragma link "TDx_SoundBuffer"
#pragma link "TDSBufferDesc"
#pragma link "TDx_Sound_Library_Install"
//---------------------------------------------------------------------------
#pragma resource "*.dfm"
//---------------------------------------------------------------------------
#define Msg(A)  {\
                if (StatusMemo->Text.Length()>30000) StatusMemo->Text = "";\
                StatusMemo->Lines->Add(A);\
                }
//---------------------------------------------------------------------------
TMainForm *MainForm;
//---------------------------------------------------------------------------
__fastcall TMainForm::TMainForm(TComponent* Owner)
    : TForm(Owner)
{
}
//---------------------------------------------------------------------------
__fastcall TMainForm::~TMainForm()
{
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::TestButtonClick(TObject *Sender)
{
Msg( "Test button was clicked, playing an example .WAV file..." );

if (Dx_Sound1->Create(NULL))
	{
    if (Dx_SoundBuffer1->CreateFromFile("TDx_Library.wav", DSBufferDesc1, Dx_Sound1))
    	{
        if (Dx_SoundBuffer1->Play(0,0))
            {
            Msg("DirectSoundBuffer is currently playing");
            while (Dx_SoundBuffer1->Playing) ; // actually, do nothing
            Msg("DirectSoundBuffer has stopped playing");
            }
        Dx_SoundBuffer1->Destroy();
        }
	Dx_Sound1->Destroy();
    }

Msg( "...finished playing the example .WAV file" );
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::QuitButtonClick(TObject *Sender)
{
Close();
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_Sound1Create(TObject *Sender)
{
/* The Level parameter defines flags indicating the priority level being requested.
   in SetCooperativeLevel(HWND pHWnd, dword pLevel)

DSSCL_EXCLUSIVE         :The application has exclusive level access to the sound
                        device. All DSSCL_PRIORITY level priviledges apply plus
                        when the application has the input focus it will be the
                        only one audible.

DSSCL_NORMAL            :The application has normal level access to the sound device.
                        The format of the primary buffer may not be changed,
                        sound output is restricted to the default 8-bit sound format.

DSSCL_PRIORITY          :The application has priority level access to the sound device.
                        Priority level access allows the use of
                        the TDx_SoundBuffer::SetFormat and Compact methods.

DSSCL_WRITEPRIMARY      :The application has write access to the primary sound buffers.
                        No secondary sound buffers can be played. This cooperative level
                        cannot be set if the DSCAPS_EMULDRIVER flag is set in the
                        associated TDSCaps component.

The application must set the cooperative level by calling this method before its buffers can
be played. The recommended cooperative level is DSSCL_PRIORITY; use other priority levels
when necessary.

*/
Msg("DirectSound interface was created successfully, setting cooperative level...");
Dx_Sound1->SetCooperativeLevel(Application->Handle, DSSCL_PRIORITY);
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_SoundBuffer1Create(TObject *Sender)
{
Msg("DirectSoundBuffer was created successfully");
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_Sound1Error(TObject *Sender, AnsiString Function,
    AnsiString Error, AnsiString ErrorMessage)
{
Msg( "An error occurred with DirectSound.");
Msg( "Function: "+Function );
Msg( "Error: "+Error );
Msg( "Error code: "+IntToStr( (int) Dx_Sound1->ErrorValue ) );
Msg( "Error message: "+ErrorMessage );
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_SoundBuffer1Error(TObject *Sender,
	AnsiString Function, AnsiString Error, AnsiString ErrorMessage)
{
Msg( "An error occurred with the DirectSoundBuffer.");
Msg( "Function: "+Function );
Msg( "Error: "+Error );
Msg( "Error code: "+IntToStr( (int) Dx_Sound1->ErrorValue ) );
Msg( "Error message: "+ErrorMessage );
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_SoundBuffer1Destroy(TObject *Sender)
{
Msg("DirectSoundBuffer is now being destroyed");
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::FormDestroy(TObject *Sender)
{
if (Dx_SoundBuffer1->Created) Dx_SoundBuffer1->Destroy();
if (Dx_Sound1->Created) Dx_Sound1->Destroy();
}
//---------------------------------------------------------------------------
