//---------------------------------------------------------------------------
// File: TMainForm.h, TDx_Library, How the Components Work - Part 2
//
// Date: 16th January, 2004
// Last Updated: 18th May 2013
// Author: Darren John Dwyer
// Copyright: (c) 2002-2013 Darren John Dwyer, All Rights Reserved.
//
// Description:
// The TDx_Library interface components have OnCreate() and OnDestroy() events,
// which you can use to easily structure code for automatic cascading of DirectX objects.
//
// This application shows how to cascade the creation and destruction of associated directx elements
// using the OnCreate() and OnDestroy() events.
//
// It creates an interface to DirectSound, then creates a DirectSoundBuffer from a .WAV file,
// starts playing the .wav, waits while the .wav is playing, destroys the DirectSoundBuffer,
// and finally destroys the DirectSound interface :-
//
//---------------------------------------------------------------------------
#ifndef TMainFormH
#define TMainFormH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Buttons.hpp>
#include <vcl\ExtCtrls.hpp>
#include "TDx_Sound.h"
#include "TDx_SoundBuffer.h"
#include "TDSBufferDesc.h"
//---------------------------------------------------------------------------
#define MAX_DEVICES 256
//---------------------------------------------------------------------------

#if (__BORLANDC__ < 0x0530) // BCB Version 1
class TMainForm : public TForm
{
#else // BCB Version 3+
class PACKAGE TMainForm : public TForm
{
#endif

__published:
//---------------------------------------------------------------------------
// Anything that is to be displayed within the Object Inspector
//---------------------------------------------------------------------------

    TMemo *StatusMemo;
    TDx_Sound *Dx_Sound1;
    TDx_SoundBuffer *Dx_SoundBuffer1;
    TDSBufferDesc *DSBufferDesc1;
	TLabel *Label1;
	TPanel *Panel1;
	TLabel *Label6;
	TGroupBox *GroupBox1;
	TLabel *Label5;
	TLabel *Label8;
	TLabel *Label14;
	TLabel *Label15;
	TLabel *Label4;
	TLabel *Label12;
	TLabel *Label13;
	TLabel *Label16;
	TLabel *Label18;
	TLabel *Label19;
	TLabel *Label20;
	TLabel *Label21;
	TLabel *Label22;
	TLabel *Label23;
	TLabel *Label24;
	TLabel *Label2;
	TLabel *Label3;
	TBitBtn *QuitButton;
	TBitBtn *TestButton;
	TLabel *Label7;

	void __fastcall Dx_Sound1Create(TObject *Sender);
	void __fastcall Dx_Sound1Destroy(TObject *Sender);
	void __fastcall Dx_Sound1Error(TObject *Sender, AnsiString Function,
	AnsiString Error, AnsiString ErrorMessage);
	void __fastcall Dx_SoundBuffer1Create(TObject *Sender);
	void __fastcall Dx_SoundBuffer1Destroy(TObject *Sender);
	void __fastcall Dx_SoundBuffer1Error(TObject *Sender, AnsiString Function,
	AnsiString Error, AnsiString ErrorMessage);
	void __fastcall Dx_SoundBuffer1BufferLost(TObject *Sender);
	void __fastcall FormDestroy(TObject *Sender);
	void __fastcall TestButtonClick(TObject *Sender);
	void __fastcall QuitButtonClick(TObject *Sender);

public:
//---------------------------------------------------------------------------
// Anything available to other classes and/or code
//---------------------------------------------------------------------------

    __fastcall TMainForm(TComponent* Owner);
    virtual __fastcall ~TMainForm();

protected:
//---------------------------------------------------------------------------
// Anything available only to classes descended from this class
//---------------------------------------------------------------------------

private:
//---------------------------------------------------------------------------
// Private data not accessible except from within this class
//---------------------------------------------------------------------------

};
//---------------------------------------------------------------------------
#if (__BORLANDC__ < 0x0530) // BCB Version 1
extern TMainForm *MainForm;
#else // BCB Version 3+
extern PACKAGE TMainForm *MainForm;
#endif
//---------------------------------------------------------------------------
#endif
//---------------------------------------------------------------------------

